import React from "react";
import { Button, Radio, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { postSysOrg, putSysOrg, getSysOrgById } from "@/service/sysorg";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";

export default (props) => {
  const { org, list, parentId, onChange } = props;

  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [form] = Form.useForm();

  const onFinish = (values) => {
    startSubmit();
    if (org?.orgId) {
      // 修改
      putSysOrg(org.orgId, values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    } else {
      // 新增
      postSysOrg(values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    }
  };

  React.useEffect(() => {
    form.resetFields();
    if (org) {
      form.setFieldsValue(org);
    } else {
      form.setFieldValue("orgPId", parentId);
      form.setFieldValue("isResponsible", true);
    }

    console.log(org, parentId);
  }, [org, parentId]);

  return (
    <Form
      onFinish={onFinish}
      form={form}
      {...formItemLayout}
      style={{ width: "90%" }}
    >
      <Form.Item
        name="name"
        label="机构名称"
        rules={[{ required: true, message: "请填写机构名称" }]}
      >
        <Input />
      </Form.Item>
      <Form.Item name="orgPId" label="上级单位">
        <Select>
          {(list || []).map((x) => (
            console.log(x),
            <Select.Option key={x.orgId}>{x.name}</Select.Option>
          ))}
        </Select>
      </Form.Item>

      <Form.Item name="isResponsible" label="责任单位">
        <Radio.Group>
          <Radio value={true}>是</Radio>
          <Radio value={false}>否</Radio>
        </Radio.Group>
      </Form.Item>

      <Form.Item name="sortNo" label="排序">
        <Input />
      </Form.Item>

      <Form.Item name="status" label="状态">
        <Select style={{ width: "100%" }} placeholder="请选择状态">
          <Select.Option value={0}>不正常</Select.Option>
          <Select.Option value={1}>正常</Select.Option>
        </Select>
      </Form.Item>
      <Form.Item {...tailFormItemLayout}>
        <Button loading={submiting} type="primary" htmlType="submit">
          保存
        </Button>
      </Form.Item>
    </Form>
  );
};
